Exports the 0.11 error chain types.
This is useful for systems that want to work with the error chain traits and types even if they are from different versions of error chain.
Structs
- Backtrace
- Representation of an owned and self-contained backtrace.
- Display
Chain - A struct which formats an error for output.
- Iter
- Iterator over the error chain using the
Error::cause()method.
Traits
- Chained
Error - This trait is implemented on all the errors generated by the
error_chainmacro. - Exit
Code - Represents a value that can be used as the exit status of the process.
See
quick_main!.